@@ -12,6 +12,9 @@ import prefs
 from .shortcuts import register_shortcut, load_shortcuts
 from .plugins import PluginManager
 
+import snaked.core.quick_open
+
+
 class Editor(SignalManager):
     editor_closed = Signal()
     request_to_open_file = Signal(str, object, return_type=object)
@@ -27,9 +30,11 @@ class Editor(SignalManager):
     push_escape_callback = Signal(object, object)
     plugins_changed = Signal()
 
-    def __init__(self):    
+    def __init__(self):
         self.uri = None
-        
+        self.session = None
+        self.opened_from = lambda: None
+                
         sw = gtk.ScrolledWindow()
         sw.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_ALWAYS)
                 
@@ -168,6 +173,9 @@ class EditorManager(object):
         load_shortcuts()
         self.register_app_shortcuts()
 
+        # Init core plugins
+        self.plugin_manager.load_core_plugin(snaked.core.quick_open)
+
     def register_app_shortcuts(self):
         register_shortcut('quit', '<ctrl>q', 'Application', 'Quit')        
         register_shortcut('close-window', '<ctrl>w', 'Window', 'Closes window')
@@ -177,10 +185,12 @@ class EditorManager(object):
         register_shortcut('new-file', '<ctrl>n', 'File',
             'Open dialog to choose new file directory and name')
         register_shortcut('show-preferences', '<ctrl>p', 'Window', 'Open preferences dialog')
+        register_shortcut('fullscreen', 'F11', 'Window', 'Toggles fullscreen mode')
         
     def open(self, filename, line=None):
         editor = Editor()
         self.editors.append(editor)
+        editor.session = self.session
         
         connect_all(self, editor)
 
@@ -189,12 +199,10 @@ class EditorManager(object):
         idle(self.plugin_manager.editor_created, editor)
         
         self.manage_editor(editor)
-        
-        if filename:
-            idle(editor.load_file, filename, line)
 
+        idle(editor.load_file, filename, line)
         idle(self.plugin_manager.editor_opened, editor)
-        
+
         return editor
 
     @lazy_property
@@ -234,17 +242,16 @@ class EditorManager(object):
 
     @Editor.editor_closed(idle=True)
     def on_editor_closed(self, editor):
-        if self.session and len(self.editors) == 1:
-            self.save_session(self.session)
-            self.session = None
+        opened_from = editor.opened_from()
+        if opened_from:
+            self.focus_editor(opened_from)
         
         self.plugin_manager.editor_closed(editor)
         self.editors.remove(editor)
-        
-        if not self.editors:
-            self.plugin_manager.quit()
-            gtk.main_quit()
 
+        if not self.editors:
+            snaked.core.quick_open.activate(self.get_fake_editor())
+        
     @Editor.change_title
     def on_editor_change_title(self, editor, title):
         self.set_editor_title(editor, title)
@@ -263,7 +270,8 @@ class EditorManager(object):
                 break
         else:
             e = self.open(filename, line)
-        
+            if editor:
+                e.opened_from = weakref.ref(editor)
         return e
 
     @Editor.request_transient_for
@@ -281,23 +289,27 @@ class EditorManager(object):
         from snaked.core.gui import new_file
         new_file.show_create_file(editor)
         
-    def quit(self, *args):
+    def quit(self, editor):
         if self.session:
-            self.save_session(self.session)
-            self.session = None
+            self.save_session(self.session, editor)
             
-        [self.close_editor(e) for e in self.editors]
+        map(self.plugin_manager.editor_closed, self.editors)
+        
+        self.plugin_manager.quit()
+        
+        if gtk.main_level() > 0:
+            gtk.main_quit()
 
-    def get_session_files(self, session):
-        self.session = session
-        from .prefs import ListSettings
-        settings = ListSettings('session-%s.db' % session)
-        return settings.load()
+    def get_session_settings(self, session):
+        from .prefs import load_json_settings
+        return load_json_settings('%s.session' % session, {})
                     
-    def save_session(self, session):
-        from .prefs import ListSettings
-        settings = ListSettings('session-%s.db' % session)
-        settings.store(e.uri for e in self.editors if e.uri)
+    def save_session(self, session, active_editor=None):
+        from .prefs import save_json_settings
+        settings = self.get_session_settings(session)
+        settings['files'] = [e.uri for e in self.editors if e.uri]
+        settings['active_file'] = active_editor.uri if active_editor else None
+        save_json_settings('%s.session' % session, settings)
 
     @Editor.push_escape_callback
     def on_push_escape_callback(self, editor, callback, args):
@@ -337,4 +349,31 @@ class EditorManager(object):
     @Editor.plugins_changed
     def on_plugins_changed(self, editor):
         for e in self.editors:
-            self.set_editor_shortcuts(e)
\ No newline at end of file
+            self.set_editor_shortcuts(e)
+
+    def get_fake_editor(self):
+        self.fake_editor = FakeEditor(self)
+        return self.fake_editor
+        
+
+class FakeEditor(object):
+    def __init__(self, manager):
+        self.project_root = None
+        self.manager = manager
+        self.request_transient_for = self
+        self.session = manager.session
+
+    def emit(self, window):
+        self.manager.set_transient_for(self, window)
+
+    def open_file(self, filename, line=None):
+        result = self.manager.open(filename, line)
+        del self.manager.fake_editor
+        self.manager.fake_editor = None
+        return result
+
+    def on_dialog_escape(self, dialog):
+        self.manager.quit(None)
+        
+    def message(self, message, timeout=None):
+        print message
\ No newline at end of file
