@@ -33,7 +33,7 @@ def infer_parameter_objects_with_hints(func):
         param_names = pyfunction.get_param_names(False)
         for i, name in enumerate(param_names):
             ptype = hintdb.get_function_param_type(pyfunction, name)
-            if ptype != None:
+            if ptype is not None:
                 params_types[i] = ptype
         
         return params_types
@@ -67,6 +67,10 @@ def get_module_attribute_with_hints(func, what):
     def inner(self, name):
         #print what, self.pycore.modname(self.resource), name
 
+        getting_name = 'getting_attr_%s' % name
+        if getattr(self, getting_name, False):
+            return func(self, name)
+
         try:
             hintdb = self.pycore.hintdb
         except AttributeError:
@@ -77,8 +81,15 @@ def get_module_attribute_with_hints(func, what):
         except exceptions.AttributeNotFoundError:
             original_pyname = None
         
-        result = hintdb.get_module_attribute(self, name, original_pyname)
-        if not result:
+        try:
+            setattr(self, getting_name, True)
+            result = hintdb.get_module_attribute(self, name, original_pyname)
+        except Exception:
+            raise
+        finally:
+            setattr(self, getting_name, False)
+            
+        if result is None:
             raise exceptions.AttributeNotFoundError()
         else:
             return result
@@ -201,7 +212,8 @@ class FileHintDb(ReHintDb):
             with open(self.hints_filename) as f:
                 for l in f:
                     try:
-                        scope, name, type = l.strip().split()
-                        self.add_hint(scope, name, type)
+                        scope, name, type = l.strip().split()[:3]
+                        if not scope.startswith('#'):
+                            self.add_hint(scope, name, type)
                     except ValueError:
                         continue
\ No newline at end of file
